<?php
/**
 * collon Theme Customizer
 *
 * @package collon
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function collon_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'collon_customize_partial_blogname',
			)
		);

		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'collon_customize_partial_blogdescription',
			)
		);	

	 // adding copyright section to the collon customizer 

    	$wp_customize-> add_section('collon_copyright_sec', array(
		'title'                    => __('Copyright','collon'),
		'description' => __('Please, type here your copyright','collon')
	 ));
	
	 $wp_customize-> add_setting('collon_copyright_set', array(
		'type'                     => 'theme_mod',
		'sanitize_callback'        => 'esc_html'
	 ));

    	$wp_customize-> add_control( 'collon_ctrl_copyright', array(
		'label'                   => __('Copyright Information','collon'),
		'description'             => __('Please, type your copyright here.','collon'),
		'section'                 => 'collon_copyright_sec',
		'settings'                => 'collon_copyright_set',
		'type'                    => 'text'
    	));

	// adding sidebar location setting to customizer
	 $wp_customize-> add_section('collon_sidebar_sec', array(
		'title'                    => __('Sidebar Location','collon'),
		'description' => __('Please, choose your sidebar location','collon')
	 ));
	

	 $wp_customize-> add_setting('collon_sidebar_set', array(
		'type'                     => 'theme_mod',
		'sanitize_callback'        => 'collon_sanitize_sidebar'
	 ));

	 $wp_customize-> add_control( 'collon_ctrl_sidebar', array(
		'label'                   => __('Sidebar Location','collon'),
		'description'             => __('Please, choose your sidebar location','collon'),
		'section'                 => 'collon_sidebar_sec',
		'settings'                => 'collon_sidebar_set',
		'type'                    => 'select',
		'choices' => array(
		'left' => __( 'Left Side','collon' ),
		'right' => __( 'Right Side','collon' ),
		'none' => __( 'Full Width','collon' ),
		  ),
	 ));

	 function collon_sanitize_sidebar($input, $setting) {

		$choices = array('right', 'left','none');
		if (in_array($input, $choices)) {
			return $input;
		} else {
			return "right";
		}
	 }


	// adding featured posts
	$wp_customize-> add_section('collon_enable_featured_post_sec', array(
		'title'                    => __('Featured Posts','collon'),
		'description' => __('Check this box to enable featured post','collon')
	 ));

	 $wp_customize-> add_setting('collon_enable_featured_post', array(
		'type'                     => 'theme_mod',
		'sanitize_callback'        => 'sanitize_checkbox_show_featured_post'
	 ));

	 $wp_customize-> add_control( 'collon_enable_featured_post_ctrl', array(
		'label'                   => __('Featured Posts','collon'),
		'description'             => __('Check this box to enable featured post','collon'),
		'section'                 => 'collon_enable_featured_post_sec',
		'settings'                => 'collon_enable_featured_post',
		'type'                    => 'checkbox',
		

	));
		
	//checkbox sanitization function adding to show featured category
	function sanitize_checkbox_show_featured_post( $input ){
					
		//returns true if checkbox is checked
			return ( isset( $input ) ? true : false );
			}
			
	//  adding show title area to the customizer

	 $wp_customize-> add_setting('collon_display_title_set', array(
		'type'                     => 'theme_mod',
		'sanitize_callback'        => 'sanitize_checkbox_show_title'
	
	 ));

	 $wp_customize-> add_control( 'collon_disp_title_ctrl', array(
		'label'                   => __('Show Title','collon'),
		'description'             => __('Check this box to show category title','collon'),
		'section'                 => 'collon_enable_featured_post_sec',
		'settings'                => 'collon_display_title_set',
		'type'                    => 'checkbox',
		
	));

	 //performing sanitization on show featured post checkbox 
	 function sanitize_checkbox_show_title( $input ){
              
		//returns true if checkbox is checked
		return ( isset( $input ) ? true : false );
	}
	

	//  adding select category to the customizer

	    //Get an array with the category list
		$collon_array_cat_full_list = get_categories(array( 'orderby' => 'name', ));
		
		//Create an empty array
		$collon_array_emp_cat_list = [];

		//Loop through the array and add the correct values every time
		foreach( $collon_array_cat_full_list as $collon_single_cat ) {
			$collon_array_emp_cat_list[$collon_single_cat->slug] = esc_html__( $collon_single_cat->name, 'collon','collon' );
		}
	
	 $wp_customize-> add_section('collon_sel_category_post_sec', array(
		'title'                    => __('Category','collon'),
		'description'              => __('Category you select here will be displayed in featured area','collon')
	 ));

	 $wp_customize-> add_setting('collon_sel_category_post', array(
		'type'       => 'theme_mod',
		'capability' => 'edit_theme_options',
		'sanitize_callback'        => 'collon_sanitize_featured_post_category'
	 ));

	 $wp_customize-> add_control( 'collon_category_post_ctrl', array(
		'label'                   => __('Category','collon'),
		'description'             => __('Category you select here will be displayed in featured area','collon'),
		'section'                 => 'collon_enable_featured_post_sec',
		'settings'                => 'collon_sel_category_post',
		'type'                    => 'select',
		'choices'                 => $collon_array_emp_cat_list, 
	));


	 function collon_sanitize_featured_post_category($input, $setting) {

		 //Get an array with the category list
		 $collon_array_cat_full_list = get_categories(array( 'orderby' => 'name', ));
		
		 //Create an empty array
		 $collon_array_emp_cat_list = [];
 
		 //Loop through the array and add the correct values every time
		 foreach( $collon_array_cat_full_list as $collon_single_cat ) {
			 $collon_array_emp_cat_list[] = $collon_single_cat->slug;
		 }

		$choices = $collon_array_emp_cat_list;
		

		
		if (in_array($input, $choices)) {
			return $input;
		} else {
			return "none";
		}
	 }
	
   }
}
add_action( 'customize_register', 'collon_customize_register' );


/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function collon_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function collon_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function collon_customize_preview_js() {
	wp_enqueue_script( 'collon-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), collon, true );
}
add_action( 'customize_preview_init', 'collon_customize_preview_js' );
